@@ -1,19 +1,10 @@
 package resource
 
 import (
+	"context"
 	"fmt"
 	"os"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
-	"github.com/openshift/cluster-image-registry-operator/pkg/resource/strategy"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
-
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
-	operatorv1 "github.com/openshift/api/operator/v1"
-	configlisters "github.com/openshift/client-go/config/listers/config/v1"
-	"github.com/openshift/library-go/pkg/operator/events"
-	"github.com/openshift/library-go/pkg/operator/resource/resourceapply"
 	appsapi "k8s.io/api/apps/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -21,6 +12,17 @@ import (
 	coreset "k8s.io/client-go/kubernetes/typed/core/v1"
 	appslisters "k8s.io/client-go/listers/apps/v1"
 	corelisters "k8s.io/client-go/listers/core/v1"
+	"k8s.io/utils/pointer"
+
+	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
+	operatorv1 "github.com/openshift/api/operator/v1"
+	configlisters "github.com/openshift/client-go/config/listers/config/v1"
+	"github.com/openshift/library-go/pkg/operator/events"
+	"github.com/openshift/library-go/pkg/operator/resource/resourceapply"
+
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
+	"github.com/openshift/cluster-image-registry-operator/pkg/resource/strategy"
+	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
 )
 
 var _ Mutator = &generatorDeployment{}
@@ -34,11 +36,10 @@ type generatorDeployment struct {
 	coreClient      coreset.CoreV1Interface
 	client          appsset.AppsV1Interface
 	driver          storage.Driver
-	params          *parameters.Globals
 	cr              *imageregistryv1.Config
 }
 
-func newGeneratorDeployment(lister appslisters.DeploymentNamespaceLister, configMapLister corelisters.ConfigMapNamespaceLister, secretLister corelisters.SecretNamespaceLister, proxyLister configlisters.ProxyLister, coreClient coreset.CoreV1Interface, client appsset.AppsV1Interface, driver storage.Driver, params *parameters.Globals, cr *imageregistryv1.Config) *generatorDeployment {
+func newGeneratorDeployment(lister appslisters.DeploymentNamespaceLister, configMapLister corelisters.ConfigMapNamespaceLister, secretLister corelisters.SecretNamespaceLister, proxyLister configlisters.ProxyLister, coreClient coreset.CoreV1Interface, client appsset.AppsV1Interface, driver storage.Driver, cr *imageregistryv1.Config) *generatorDeployment {
 	return &generatorDeployment{
 		recorder:        events.NewLoggingEventRecorder("image-registry-operator"),
 		lister:          lister,
@@ -48,7 +49,6 @@ func newGeneratorDeployment(lister appslisters.DeploymentNamespaceLister, config
 		coreClient:      coreClient,
 		client:          client,
 		driver:          driver,
-		params:          params,
 		cr:              cr,
 	}
 }
@@ -66,7 +66,7 @@ func (gd *generatorDeployment) GetResource() string {
 }
 
 func (gd *generatorDeployment) GetNamespace() string {
-	return gd.params.Deployment.Namespace
+	return defaults.ImageRegistryOperatorNamespace
 }
 
 func (gd *generatorDeployment) GetName() string {
@@ -78,7 +78,7 @@ func (gd *generatorDeployment) expected() (runtime.Object, error) {
 		return nil, fmt.Errorf("no storage driver present")
 	}
 
-	podTemplateSpec, deps, err := makePodTemplateSpec(gd.coreClient, gd.proxyLister, gd.driver, gd.params, gd.cr)
+	podTemplateSpec, deps, err := makePodTemplateSpec(gd.coreClient, gd.proxyLister, gd.driver, gd.cr)
 	if err != nil {
 		return nil, err
 	}
@@ -91,7 +91,7 @@ func (gd *generatorDeployment) expected() (runtime.Object, error) {
 	if podTemplateSpec.Annotations == nil {
 		podTemplateSpec.Annotations = map[string]string{}
 	}
-	podTemplateSpec.Annotations[parameters.ChecksumOperatorDepsAnnotation] = depsChecksum
+	podTemplateSpec.Annotations[defaults.ChecksumOperatorDepsAnnotation] = depsChecksum
 
 	// Strategy defaults to RollingUpdate
 	deployStrategy := gd.cr.Spec.RolloutStrategy
@@ -103,15 +103,16 @@ func (gd *generatorDeployment) expected() (runtime.Object, error) {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      gd.GetName(),
 			Namespace: gd.GetNamespace(),
-			Labels:    gd.params.Deployment.Labels,
+			Labels:    defaults.DeploymentLabels,
 			Annotations: map[string]string{
 				defaults.VersionAnnotation: os.Getenv("RELEASE_VERSION"),
 			},
 		},
 		Spec: appsapi.DeploymentSpec{
-			Replicas: &gd.cr.Spec.Replicas,
+			ProgressDeadlineSeconds: pointer.Int32Ptr(60),
+			Replicas:                &gd.cr.Spec.Replicas,
 			Selector: &metav1.LabelSelector{
-				MatchLabels: gd.params.Deployment.Labels,
+				MatchLabels: defaults.DeploymentLabels,
 			},
 			Template: podTemplateSpec,
 			Strategy: appsapi.DeploymentStrategy{
@@ -124,7 +125,7 @@ func (gd *generatorDeployment) expected() (runtime.Object, error) {
 	if err != nil {
 		return nil, err
 	}
-	deploy.ObjectMeta.Annotations[parameters.ChecksumOperatorAnnotation] = dgst
+	deploy.ObjectMeta.Annotations[defaults.ChecksumOperatorAnnotation] = dgst
 
 	return deploy, nil
 }
@@ -140,7 +141,7 @@ func (gd *generatorDeployment) Create() (runtime.Object, error) {
 	}
 
 	dep, _, err := resourceapply.ApplyDeployment(
-		gd.client, gd.recorder, exp.(*appsapi.Deployment), -1, false,
+		gd.client, gd.recorder, exp.(*appsapi.Deployment), -1,
 	)
 	if err != nil {
 		return nil, err
@@ -157,7 +158,7 @@ func (gd *generatorDeployment) Update(o runtime.Object) (runtime.Object, bool, e
 	}
 
 	dep, updated, err := resourceapply.ApplyDeployment(
-		gd.client, gd.recorder, exp.(*appsapi.Deployment), gd.LastGeneration(), false,
+		gd.client, gd.recorder, exp.(*appsapi.Deployment), gd.LastGeneration(),
 	)
 	if err != nil {
 		return o, false, err
@@ -207,8 +208,10 @@ func (gd *generatorDeployment) LastGeneration() int64 {
 	return -1
 }
 
-func (gd *generatorDeployment) Delete(opts *metav1.DeleteOptions) error {
-	return gd.client.Deployments(gd.GetNamespace()).Delete(gd.GetName(), opts)
+func (gd *generatorDeployment) Delete(opts metav1.DeleteOptions) error {
+	return gd.client.Deployments(gd.GetNamespace()).Delete(
+		context.TODO(), gd.GetName(), opts,
+	)
 }
 
 func (g *generatorDeployment) Owned() bool {
